@@ -1,5 +1,5 @@
 
-shinyplotgroup<- function(fit, xl, xu, lpw){
+shinyplotgroup<- function(fit, xl, xu, lpw, lwd){
   
   if(length(unique(fit$limits[,1]))>1 | length(unique(fit$limits[,2]))>1 ){stop("Parameter limits must be the same for each expert")}
   
@@ -7,10 +7,10 @@ shinyplotgroup<- function(fit, xl, xu, lpw){
   
   # Determine set of suitable distributions
   if(fit$limits[1, 1]>=0 & fit$limits[1, 2] < Inf){
-    distributionchoices <- list("Histogram" = 1, "Normal" = 2, "Student t" = 3, "Gamma" = 4, "log normal" = 5, "Log Student t" = 6, "Beta" = 7, "Best fitting" =8)
+    distributionchoices <- list("Histogram" = 1, "Normal" = 2, "Student t" = 3, "Gamma" = 4, "Log normal" = 5, "Log Student t" = 6, "Beta" = 7, "Best fitting" =8)
   }
   if(fit$limits[1, 1]>=0 & fit$limits[1, 2] == Inf){
-    distributionchoices <- list("Histogram" = 1, "Normal" = 2, "Student t" = 3, "Gamma" = 4, "log normal" = 5, "Log Student t" = 6, "Best fitting" =8)
+    distributionchoices <- list("Histogram" = 1, "Normal" = 2, "Student t" = 3, "Gamma" = 4, "Log normal" = 5, "Log Student t" = 6, "Best fitting" =8)
   }
   if(fit$limits[1, 1]==-Inf & fit$limits[1, 2] == Inf){
     distributionchoices <- list("Histogram" = 1, "Normal" = 2, "Student t" = 3, "Best fitting" =8)
@@ -55,11 +55,12 @@ shinyplotgroup<- function(fit, xl, xu, lpw){
       if(is.null(input$lp)){
         print(makeGroupPlot(fit, pl = xlimits[1], 
                                  pu = xlimits[2], 
-                                 d=dist[as.numeric(input$radio)]))
+                                 d=dist[as.numeric(input$radio)],
+                            lwd))
       }else{
         print(makeLinearPoolPlot(fit, xl = xlimits[1], 
                                  xu = xlimits[2], 
-                                 d=dist[as.numeric(input$radio)], w = lpw))
+                                 d=dist[as.numeric(input$radio)], w = lpw, lwd))
       }
      
     })
